package Sah::SchemaR::dns::record::ns;

our $DATE = '2019-07-25'; # DATE
our $VERSION = '0.002'; # VERSION

our $rschema = ["hash",[{keys=>{host=>["net::hostname",{req=>1},{}],name=>["str",{req=>1},{}],prio=>["uint",{req=>1},{}],ttl=>["uint",{},{}],type=>["str",{is=>"NS",match=>"\\A(?:[A-Z]([A-Z0-9]+|[A-Z0-9-]*[A-Z0-9])?|\\*)\\z",req=>1},{}]},"keys.restrict"=>1,req_keys=>["name","type","host"],summary=>"DNS NS record"}],["dns::record","hash"]];

1;
# ABSTRACT: DNS NS record

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::SchemaR::dns::record::ns - DNS NS record

=head1 VERSION

This document describes version 0.002 of Sah::SchemaR::dns::record::ns (from Perl distribution Sah-Schemas-DNS), released on 2019-07-25.

=head1 DESCRIPTION

This module is automatically generated by Dist::Zilla::Plugin::Sah::Schemas during distribution build.

A Sah::SchemaR::* module is useful if a client wants to quickly lookup the base type of a schema without having to do any extra resolving. With Sah::Schema::*, one might need to do several lookups if a schema is based on another schema, and so on. Compare for example L<Sah::Schema::poseven> vs L<Sah::SchemaR::poseven>, where in Sah::SchemaR::poseven one can immediately get that the base type is C<int>. Currently L<Perinci::Sub::Complete> uses Sah::SchemaR::* instead of Sah::Schema::* for reduced startup overhead when doing tab completion.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-DNS>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-DNS>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-DNS>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
